@@ -11,7 +11,7 @@ use Carp 'confess';
 use Sub::Uplevel qw(uplevel);
 use Test::Builder;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @EXPORT = qw(expected_dataset_ok dataset_ok expected_xml_dataset_ok xml_dataset_ok reset_schema_ok populate_schema_ok reset_sequence_ok set_refresh_load_strategy set_insert_load_strategy test_connection test_dbh);
 
 
@@ -79,7 +79,7 @@ Database test framework to verify that your database data match expected set of
 
 =head2 Managing test data
 
-    Database tests should giving you complete and fine grained control over the test data that is used.
+Database tests should giving you complete and fine grained control over the test data that is used.
 
     use Test::DBUnit dsn => $dsn, username => $username, password => $password;
     reset_schema_ok('t/sql/create_schema.sql');
@@ -88,9 +88,9 @@ Database test framework to verify that your database data match expected set of
 
 =head2 Loading test data sets
 
-    Before you want to test your business logic it is essential to have repeatable snapshot of your
-    tables you want to test, so this module allows you populate/synchronize your database with
-    the passed in data structure or with the xml content.
+Before you want to test your business logic it is essential to have repeatable snapshot of your
+tables you want to test, so this module allows you populate/synchronize your database with
+the passed in data structure or with the xml content.
 
     dataset_ok(
         emp => [ename => "john", deptno => "10", job => "project manager"],
@@ -115,8 +115,8 @@ Database test framework to verify that your database data match expected set of
 
 =head2 Verifying test results
 
-    It can be useful to use data sets for checking the contents of a database after is has been modified by a test.
-    You may want to check the result of a update/insert/delete method or a stored procedure.
+It can be useful to use data sets for checking the contents of a database after is has been modified by a test.
+You may want to check the result of a update/insert/delete method or a stored procedure.
 
     expected_dataset_ok(
         emp   => [empno => "1", ename => "Scott", deptno => "10", job => "project manager"],
@@ -125,8 +125,10 @@ Database test framework to verify that your database data match expected set of
         bonus => [ename => "scott", job => "project manager", sal => "20"],
     )
     or
+
     expected_xml_dataset_ok('test1');
     t/test_unit.test1-result.xml #given that you testing module is t/test_unit.t
+
     <?xml version='1.0' encoding='UTF-8'?>
     <dataset>
         <emp empno="1" ename="Scott" deptno="10" job="project manager" />
@@ -136,11 +138,12 @@ Database test framework to verify that your database data match expected set of
     </dataset>
 
 =head2 Configuring the dataset load strategy
-    By default, datasets are loaded into the database using an insert load strategy.
-    This means that all data in the tables that are present in the dataset is deleted,
-    after which the test data records are inserted. Order in with all data is deleted
-    depends on reverse table occurrence in the dataset, however you may force order of
-    data by specifying empty table:
+
+By default, datasets are loaded into the database using an insert load strategy.
+This means that all data in the tables that are present in the dataset is deleted,
+after which the test data records are inserted. Order in with all data is deleted
+depends on reverse table occurrence in the dataset, however you may force order of
+data by specifying empty table:
 
         table1 => [],  #this fore delete operation in occurrence order
         table1 => [col1 => 1, col2 => 'some data'],    
@@ -148,9 +151,9 @@ Database test framework to verify that your database data match expected set of
         <table1 />
         <table1 col1="1" col2="some data"/>
 
-    In this strategy number of rows will be validated against datasets in (xml_)expexted_dataset_ok method.
-    Load strategy behavior is configurable,
-    it can be modified by calling:
+In this strategy number of rows will be validated against datasets in (xml_)expexted_dataset_ok method.
+Load strategy behavior is configurable,
+it can be modified by calling:
 
     set_insert_load_strategy();
     or in XML
@@ -168,19 +171,21 @@ Database test framework to verify that your database data match expected set of
         ....
     </dataset>
 
-    The alternative to the insert load strategy is refresh load strategy.
-    In this case update on existing rows will take place or insert occurs if rows are missing.
+The alternative to the insert load strategy is refresh load strategy.
+In this case update on existing rows will take place or insert occurs if rows are missing.
 
 
 =head2 Working with sequences
-    You may use sequences or autogenerated features, so this module allows you handle that.
+
+You may use sequences or autogenerated features, so this module allows you handle that.
 
     reset_sequence_ok('emp_seq');
     or for MySQL
     reset_sequence_ok('test_table_name')
 
-    #the ALTER TABLE test_table_name AUTO_INCREMENT = 1 will be issued
-    #Note that for MySQL the test_table_name must be empty.
+The ALTER TABLE test_table_name AUTO_INCREMENT = 1 will be issued
+Note that for MySQL reset sequence the test_table_name must be empty.
+
     or in XML
     <?xml version='1.0' encoding='UTF-8'?>
     <dataset reset_sequences="emp_seq, dept_seq">
@@ -248,7 +253,7 @@ Database test framework to verify that your database data match expected set of
     reset_sequence_ok('emp_seq');
     ....
 
-=head3 Autogenerated fileds tests with MySQL
+=head3 Autogenerated filed values tests with MySQL
 
     t/sql/create_schema.sql
     CREATE TABLE emp(
@@ -292,9 +297,7 @@ reset_sequence_ok
 set_refresh_load_strateg
 set_insert_load_strateg
 connnection
-dbh
-
-by default.
+dbh by default.
 
 =head2 METHODS
 
@@ -386,7 +389,8 @@ Tests database schema population using sql file. Takes file name as parameter.
 
 =item reset_sequence_ok
 
-    Resets database sequence. Takes sequence name as parameter.
+Resets database sequence. Takes sequence name as parameter.
+
     use Test::More tests => $tests; 
     use Test::DBUnit dsn => $dsn, username => $username, password => $password;
 
@@ -421,12 +425,12 @@ for instance
 the following invocation xml_dataset_ok('test1') from t/sub_dir/001_test.t file will
 expect t/sub_dir/001_test.test1.xml file.
 
-<dataset load_strategy="INSERT_LOAD_STRATEGY" reset_sequences="emp_seq">
-    <emp ename="scott" deptno="10" job="project manager" />
-    <emp ename="john"  deptno="10" job="engineer" />
-    <emp ename="mark"  deptno="10" job="sales assistant" />
-    <bonus ename="scott" job="project manager" sal="20" />
-</dataset>
+    <dataset load_strategy="INSERT_LOAD_STRATEGY" reset_sequences="emp_seq">
+        <emp ename="scott" deptno="10" job="project manager" />
+        <emp ename="john"  deptno="10" job="engineer" />
+        <emp ename="mark"  deptno="10" job="sales assistant" />
+        <bonus ename="scott" job="project manager" sal="20" />
+    </dataset>
 
 
 =cut
@@ -459,12 +463,12 @@ for instance
 the following invocation xml_dataset_ok('test1') from t/sub_dir/001_test.t file will
 expect t/sub_dir/001_test.test1.xml file.
 
-<dataset load_strategy="INSERT_LOAD_STRATEGY" reset_sequences="emp_seq,dept_seq">
-    <emp ename="Scott" deptno="10" job="project manager" />
-    <emp ename="John"  deptno="10" job="engineer" />
-    <emp ename="Mark"  deptno="10" job="sales assistant" />
-    <bonus ename="Scott" job="project manager" sal="20" />
-</dataset>
+    <dataset load_strategy="INSERT_LOAD_STRATEGY" reset_sequences="emp_seq,dept_seq">
+        <emp ename="Scott" deptno="10" job="project manager" />
+        <emp ename="John"  deptno="10" job="engineer" />
+        <emp ename="Mark"  deptno="10" job="sales assistant" />
+        <bonus ename="Scott" job="project manager" sal="20" />
+    </dataset>
 
 =cut
 
@@ -492,12 +496,12 @@ expect t/sub_dir/001_test.test1.xml file.
 
 Tests database schema population/synch to the passed in dataset.
 
-dataset_ok(
-    table1 => [], #this deletes all data from table1 (DELETE FROM table1)
-    table2 => [], #this deletes all data from table2 (DELETE FROM table2)
-    table1 => [col1 => 'va1', col2 => 'val2'], #this insert or update depend on strategy
-    table1 => [col1 => 'xval1', col2 => 'xval2'],
-)
+    dataset_ok(
+        table1 => [], #this deletes all data from table1 (DELETE FROM table1)
+        table2 => [], #this deletes all data from table2 (DELETE FROM table2)
+        table1 => [col1 => 'va1', col2 => 'val2'], #this insert or update depend on strategy
+        table1 => [col1 => 'xval1', col2 => 'xval2'],
+    )
 
 =cut
 
@@ -519,9 +523,10 @@ dataset_ok(
 =item expected_dataset_ok
 
 Validates database schema against passed in dataset.
-expected_dataset_ok(
-    table1 => [col1 => 'va1', col2 => 'val2'], 
-)
+
+    expected_dataset_ok(
+        table1 => [col1 => 'va1', col2 => 'val2'], 
+    )
 
 =cut
 
